==> validoopsie-1.4.0-py3-none-any.whl: validoopsie/validation_catalogue/UniqueValidation/column_unique_pair.py <==
from __future__ import annotations

import narwhals as nw
from narwhals.typing import FrameT

from validoopsie.base import BaseValidationParameters, base_validation_wrapper


@base_validation_wrapper
class ColumnUniquePair(BaseValidationParameters):
    """Validates the uniqueness of combined values from multiple columns.

    This class checks if the combination of values from specified columns creates unique
    entries in the dataset. For example, if checking columns ['first_name', 'last_name'],
    the combination of these values should be unique for each row.

    Parameters
      column_list (list | tuple): List or tuple of column names to check for unique
          combinations.
      threshold (float, optional): Threshold for validation. Defaults to 0.0.
      impact (Literal["low", "medium", "high"], optional): Impact level of validation.
          Defaults to "low".

    """

    def __init__(
        self,
        column_list: list | tuple,
        *args,
        **kwargs,
    ) -> None:
        assert len(column_list) > 0, "At least two columns are required."

        self.column_list = column_list
        column = " - ".join(column_list)
        super().__init__(column, *args, **kwargs)

    @property
    def fail_message(self) -> str:
        """Return a descriptive message when the validation fails."""
        return (
            f"Duplicate entries found: The combination of columns [{self.column}] "
            "contains non-unique values."
        )

    def __call__(self, frame: FrameT) -> FrameT:
        """Check if the unique values are in the list."""
        return (
            frame.with_columns(
                nw.concat_str(
                    [nw.col(col) for col in self.column_list],
                    separator=" - ",
                ).alias(self.column),
            )
            .group_by(self.column)
            .agg(nw.len().alias(f"{self.column}-count"))
            .filter(nw.col(f"{self.column}-count") > 1)
        )

==> validoopsie-1.4.2-py3-none-any.whl: validoopsie/validation_catalogue/UniqueValidation/column_unique_pair.py <==
from __future__ import annotations

from typing import Literal, Optional

import narwhals as nw
from narwhals.typing import Frame, IntoFrame

from validoopsie.base import BaseValidationParameters, base_validation_wrapper


@base_validation_wrapper
class ColumnUniquePair(BaseValidationParameters):
    """Validates the uniqueness of combined values from multiple columns.

    This class checks if the combination of values from specified columns creates unique
    entries in the dataset. For example, if checking columns ['first_name', 'last_name'],
    the combination of these values should be unique for each row.

    Parameters
      column_list (list | tuple): List or tuple of column names to check for unique
          combinations.
      threshold (float, optional): Threshold for validation. Defaults to 0.0.
      impact (Literal["low", "medium", "high"], optional): Impact level of validation.
          Defaults to "low".

    """

    def __init__(
        self,
        column_list: list[str] | tuple[str, ...],
        impact: Literal["low", "medium", "high"] = "low",
        threshold: Optional[float] = 0.00,
        **kwargs: dict[str, object],
    ) -> None:
        assert len(column_list) > 0, "At least two columns are required."

        self.column_list = column_list
        column = " - ".join(column_list)
        super().__init__(column, impact, threshold, **kwargs)

    @property
    def fail_message(self) -> str:
        """Return a descriptive message when the validation fails."""
        return (
            f"Duplicate entries found: The combination of columns [{self.column}] "
            "contains non-unique values."
        )

    def __call__(self, frame: Frame) -> IntoFrame:
        """Check if the unique values are in the list."""
        return (
            frame.with_columns(
                nw.concat_str(
                    [nw.col(col) for col in self.column_list],
                    separator=" - ",
                ).alias(self.column),
            )
            .group_by(self.column)
            .agg(nw.len().alias(f"{self.column}-count"))
            .filter(nw.col(f"{self.column}-count") > 1)
        )
